---
feature_story: FS_07_10_10_74
feature_title: relay to another server
feature_status: TODO
---

There should be a way to bind some commands (e.g. via FS_01_89_09_24 interp tree) to relay request to another
`argrelay` server.
